Going Gray: Perfect Wardrobe : Details
Author: Details Magazine
Description: This season, designers updated a classic color by way of modern silhouettes both tailored and casual. The verdict? The most effortless way to transition into fall is all in the shading.
Keywords: style and advice, perfect wardrobe, Menswear, gray suits, gray shirts, gray pants, gray coats, gray sweaters, fashion and style, fashion, style

Close

### Now
Trending

### 10 Home Design Predictions for 2015

### The Best-Dressed Men of 2014

### New Year's Resolutions Guide

- Home
- Fashion & Style
- Perfect Wardrobe

# Going Gray

## This season, designers updated a classic color by way of modern silhouettes both tailored and casual. The verdict? The most effortless way to transition into fall is all in the shading.

Photographs by Robert Nethery
Friday, August 01, 2014

- Print

Play Slideshow
Pause
View Larger
View All Thumbnails
Previous
1 of 10
Next

Blazer and vest by Ermenegildo Zegna Couture. Shirt by Carven.

Styling by Benjamin Sturgill. Grooming by Martin-Christopher Harper at Platform using Aveda. Casting by Edward Kim at The Edit Desk.

Keywords
  style and advice,
  perfect wardrobe,
  fashion and style,
  fashion,
  style

- Share

Replay

##### Newsletter Sign Up

Enter your e-mail address

- Get the latest in men's style, grooming, diet, fitness and pop-culture trends every Wednesday. See Sample
- Get the most popular articles, blog posts, and slideshows of the past week every Saturday. See Sample

I understand and agree that registration on or use of this site constitutes agreement to its User Agreement, and Privacy Policy.
AROUND THE WEB
ZergNet
Powered By ZergNet

### most viewed

## Ultimate Guides

##### Hair Styles

##### Exercise

##### Watches

##### Street Style

##### Resolutions

##### Classic American Menswear

##### Travel

##### Grooming

##### Celebrity Style